;; Copyright (C) 2001 Peter Seibel

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2 of the
;; License, or (at your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
;; USA

(require 'p4)

(defvar p4-workspaces nil)
(defvar p4-workspace-names nil)
(defvar p4-workspace-ports nil)

(defun p4-add-workspace (client-name client-port)
  "Add a new p4 workspace to the set emacs knows about."
  (interactive "sClient name: \nsP4 port: ")
  (let ((joined (concat client-name "@" client-port)))
    (if (not (member joined p4-workspaces))
	(progn
	  (setq p4-workspaces (cons joined p4-workspaces))
	  (setq p4-workspace-names 
		(cons `(,joined . ,client-name) p4-workspace-names))
	  (setq p4-workspace-ports
		(cons `(,joined . ,client-port) p4-workspace-ports)))))
  p4-workspaces)
      
(defun p4-workspace ()
  "Choose a p4 workspace."
  (interactive)
  (let* ((workspace
	  (read-from-minibuffer
	   "Source root: " (car p4-workspaces)
	   nil nil 'p4-workspaces nil))
	 (client-name (cdr (assoc workspace p4-workspace-names)))
	 (client-port (cdr (assoc workspace p4-workspace-ports))))
    (setenv "P4CLIENT" client-name)
    (setenv "P4PORT" client-port)
    (setq p4-workspace (p4-find-workspace))))

(provide 'p4-workspace)
